public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] gentoo-x86 commit in app-pda/gnome-pilot/files: gnome-pilot-2.0.16-hal-0.5.11.patch
@ 2008-08-06 22:28 Gilles Dartiguelongue (eva)
  0 siblings, 0 replies; 2+ messages in thread
From: Gilles Dartiguelongue (eva) @ 2008-08-06 22:28 UTC (permalink / raw
  To: gentoo-commits

eva         08/08/06 22:28:27

  Added:                gnome-pilot-2.0.16-hal-0.5.11.patch
  Log:
  add patch to fix detection with hal-0.5.11, bug #231678.
  (Portage version: 2.2_rc3/cvs/Linux 2.6.26-gentoo-mactel x86_64)

Revision  Changes    Path
1.1                  app-pda/gnome-pilot/files/gnome-pilot-2.0.16-hal-0.5.11.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/app-pda/gnome-pilot/files/gnome-pilot-2.0.16-hal-0.5.11.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/app-pda/gnome-pilot/files/gnome-pilot-2.0.16-hal-0.5.11.patch?rev=1.1&content-type=text/plain

Index: gnome-pilot-2.0.16-hal-0.5.11.patch
===================================================================
--- gpilotd/gpilotd.c-old	2008-07-13 21:52:04.000000000 +1000
+++ gpilotd/gpilotd.c	2008-07-13 21:53:30.000000000 +1000
@@ -1079,7 +1079,7 @@
 hal_device_added (LibHalContext *ctx, const char *udi)
 {
 	gboolean visor_net = FALSE;
-	char *bus, *match_str;
+	char *bus, *platform, *match_str;
 	int vendor_id, product_id, i;
 	GPilotDevice *device;
 	DBusError error;
@@ -1090,15 +1090,23 @@
 
 	load_devices_xml ();
 
 	/* HAL match rule: we look for info.bus == 'usb_device'
 	 * and then try to match the usb_device.product_id and usb_device.vendor_id
 	 * against the list in devices.xml.
 	 */
-	if (!(bus = libhal_device_get_property_string (hal_ctx, udi, "info.bus", NULL)))
+	if (platform = libhal_device_get_property_string (hal_ctx, udi, "pda.platform", NULL)) {
+	    if (strcmp (platform, "palm") != 0) {
+		libhal_free_string (platform);
 		return;
-	if (strcmp (bus, "usb_device") != 0) {
+	    }
+	} else if (bus = libhal_device_get_property_string (hal_ctx, udi, "info.bus", NULL)) {
+	    if (strcmp (bus, "usb_device") != 0) {
 		libhal_free_string (bus);
 		return;
+	    }
+	} else {
+	    return;
 	}
 
 	dbus_error_init (&error);






^ permalink raw reply	[flat|nested] 2+ messages in thread

* [gentoo-commits] gentoo-x86 commit in app-pda/gnome-pilot/files: gnome-pilot-2.0.16-hal-0.5.11.patch
@ 2009-09-27 23:38 Gilles Dartiguelongue (eva)
  0 siblings, 0 replies; 2+ messages in thread
From: Gilles Dartiguelongue (eva) @ 2009-09-27 23:38 UTC (permalink / raw
  To: gentoo-commits

eva         09/09/27 23:38:26

  Removed:              gnome-pilot-2.0.16-hal-0.5.11.patch
  Log:
  Add missing scrollkeeper dependency, bug #285596. Clean up old revisions
  (Portage version: 2.2_rc42/cvs/Linux x86_64)



^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2009-09-27 23:38 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2009-09-27 23:38 [gentoo-commits] gentoo-x86 commit in app-pda/gnome-pilot/files: gnome-pilot-2.0.16-hal-0.5.11.patch Gilles Dartiguelongue (eva)
  -- strict thread matches above, loose matches on Subject: below --
@@ -1090,15 +1090,23 @@
 	load_devices_xml ();
 
-	/* HAL match rule: we look for info.bus == 'usb_device'
+	/* HAL match rule: we look for pda.platform == 'palm'
+	 * (or the legacy info.bus == 'usb_device')
 	 * and then try to match the usb_device.product_id and usb_device.vendor_id
 	 * against the list in devices.xml.
2008-08-06 22:28 Gilles Dartiguelongue (eva)

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox